# <span class="badge package-variant-dataquery"></span> testdata

## Objects

 * <span class="badge object-type-class"></span> [CSVWave](./object-CSVWave.md)
 * <span class="badge object-type-class"></span> [Key](./object-Key.md)
 * <span class="badge object-type-class"></span> [NodesQuery](./object-NodesQuery.md)
 * <span class="badge object-type-class"></span> [PulseWaveQuery](./object-PulseWaveQuery.md)
 * <span class="badge object-type-class"></span> [Scenario](./object-Scenario.md)
 * <span class="badge object-type-class"></span> [SimulationQuery](./object-SimulationQuery.md)
 * <span class="badge object-type-class"></span> [StreamingQuery](./object-StreamingQuery.md)
 * <span class="badge object-type-enum"></span> [TestDataQueryType](./object-TestDataQueryType.md)
 * <span class="badge object-type-class"></span> [USAQuery](./object-USAQuery.md)
 * <span class="badge object-type-class"></span> [Dataquery](./object-Dataquery.md)
## Builders

 * <span class="badge builder"></span> [CSVWave](./builder-CSVWave.md)
 * <span class="badge builder"></span> [Key](./builder-Key.md)
 * <span class="badge builder"></span> [NodesQuery](./builder-NodesQuery.md)
 * <span class="badge builder"></span> [PulseWaveQuery](./builder-PulseWaveQuery.md)
 * <span class="badge builder"></span> [Scenario](./builder-Scenario.md)
 * <span class="badge builder"></span> [SimulationQuery](./builder-SimulationQuery.md)
 * <span class="badge builder"></span> [StreamingQuery](./builder-StreamingQuery.md)
 * <span class="badge builder"></span> [USAQuery](./builder-USAQuery.md)
 * <span class="badge builder"></span> [Dataquery](./builder-Dataquery.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to testdata data queries.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.DataqueryConfig
```

